#!/usr/bin/perl
#
# Copyright 2009 Teleflora
# $Revision: 1.9 $
#
# Install "RTI Admin Menus" as well as associated "tfremote" service.
#
use strict;
use warnings;
use English;
use Getopt::Long;
use POSIX;


my $RTIDIR="/usr2/bbx";
my $RUN = 0;
my $VERSION = 0;
my $HELP = 0;

GetOptions(
	"run" => \$RUN,
	"version" => \$VERSION,
	"help" => \$HELP
);

# --version
if($VERSION != 0) {
	print('$Revision: 1.9 $' . "\n");
	exit(0);
}


# --help
if($HELP != 0) {
	usage();
	exit(0);
}

# --run
if($RUN == 0) {
	usage();
	exit(1);
}

loginfo("Installing RTI Admin Menus Patch.");
if($EUID != 0) {
	loginfo("Error: Must be root to run this script.");
	exit(2);
}
	


loginfo("Verify patch files...");
foreach ("tfsupport.pl", "tfsupport-authorized_keys", "tfremote.pl", "killterms.pl") {
	if(! -f "$_") {
		loginfo("Error: $_ $!");
		exit(3);
	}
}




# Move tfsupport script into place.
loginfo("Copy admin menus...");
system("cp -f tfsupport.pl $RTIDIR/bin/tfsupport.pl");
if(! -f "$RTIDIR/bin/tfsupport.pl") {
	loginfo("cp tfsupport.pl failed \"$!\"...");
	exit(7);
}
system("chown tfsupport:root $RTIDIR/bin/tfsupport.pl");
system("chmod 555 $RTIDIR/bin/tfsupport.pl");


loginfo("Admin menu sudo setup...");
system("RTI_DIR=$RTIDIR $RTIDIR/bin/tfsupport.pl --sudosetup");


# Move authorized keys file into place.
loginfo("Copy tfsupport-authorized_keys Into Place...");
system("$RTIDIR/bin/tfsupport.pl --installkeys tfsupport-authorized_keys");
system("$RTIDIR/bin/tfsupport.pl --sudosetup");


# Update killterms.pl
loginfo("Copy killterms.pl...");
system("cp -f killterms.pl $RTIDIR/bin/killterms.pl");
if(! -f "$RTIDIR/bin/killterms.pl") {
	loginfo("cp killterms.pl failed \"$!\"...");
	exit(7);
}
system("chown tfsupport:root $RTIDIR/bin/killterms.pl");
system("chmod 555 $RTIDIR/bin/killterms.pl");




# Copy tfremote script into place.
loginfo("Copy tfremote script...");
system("cp -f tfremote.pl $RTIDIR/bin/tfremote.pl");
if(! -f "$RTIDIR/bin/tfremote.pl") {
	loginfo("cp tfremote.pl failed \"$!\"...\n");
	exit(6);
}
system("chown tfsupport:root $RTIDIR/bin/tfremote.pl");
system("chmod 555 $RTIDIR/bin/tfremote.pl");



# Setup tfremote service.
loginfo("Setup tfremote service.");
system("$RTIDIR/bin/tfremote.pl --setup");
if($? != 0) {
	loginfo("Error: $RTIDIR/bin/tfremote.pl --setup failed with error code $?\n");
}
loginfo("Restart tfremote service.");
system("/sbin/service tfremote restart");
if($? != 0) {
	loginfo("Error: 'tfremote' service did not restart. Returned error $?\n");
}


loginfo("(Re)start sshd service.");
system("/sbin/service sshd start");

loginfo("Admin Menus Patch Complete.");
exit(0);

###########################################################################
###########################################################################
###########################################################################


sub usage
{
	print("Usage:\n");
	print("$0 --help\n");
	print("$0 --version\n");
	print("$0 --run\n");

}

sub loginfo
{
	my $message = $_[0];
	my $timestamp = "";


	$timestamp = strftime("%Y-%m-%d %H:%M:%S", localtime());
	open(LOG, ">> $RTIDIR/log/RTI-Patches.log");
	print(LOG "$timestamp $$ $message\n");
	close(LOG);
	print("$timestamp $$ $message\n");


}
